@@ -10,7 +10,7 @@ setMethod("lapply", "RangedData",
           function(X, FUN, ...)
           {
             what <- "\"lapply\" method for RangedData objects"
-            .Deprecated(msg=wmsg(RangedData_method_is_deprecated_msg(what)))
+            .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
             FUN <- match.fun(FUN)
             inds <- structure(seq(length(X)), names = names(X))
             lapply(inds, function(i) FUN(X[i], ...))
@@ -24,7 +24,7 @@ setMethod("within", "RangedData",
           function(data, expr, ...)
           {
             what <- "\"within\" method for RangedData objects"
-            .Deprecated(msg=wmsg(RangedData_method_is_deprecated_msg(what)))
+            .Defunct(msg=wmsg(RangedData_method_is_defunct_msg(what)))
             e <- list2env(as.list(as(data, "DataFrame")))
             e$ranges <- ranges(data)
             S4Vectors:::safeEval(substitute(expr), e, S4Vectors:::top_prenv(expr))
